import Qt 4.7
import "../Common.js" as Common
import "../fonts" as Fonts
import "../Colors.js" as Colors

Rectangle
{
    id:choiceBar;
    objectName:	"choiceBar"
    property double verticalMargin: 16

    property variant buttonListModel
    property variant localizer

    property alias caption: headerText.text
    property alias captionLeftImage: headerImage.source
    property alias description: description.text
    property alias shouldShowReserveCode: reserveCode.visible

    property variant model

    property int maxHeight: 100
    property int contentHeight: scrollPane.contentHeight

    property variant commonFontStyles: Fonts.Common{}

    height: maxHeight > contentHeight ? contentHeight : maxHeight;
	
    radius: 5
    color: Colors.grayArea;

    clip:true

    Rectangle
    {
            color: parent.color;
            anchors.fill: parent
            anchors.leftMargin: parent.radius
    }

    function getButtonIcon(buttonIcon)
    {
        var map = {
           0 :"", //"NoIcon"
           1 :"../images/license/ico_buy_16_gray.png", //"BuyIcon"
           2 :"../images/license/BackToKAV_ico.png", //"RollbackIcon"
           3 :"../images/license/ico_support_16_gray.png", //"SupportIcon"
           4 :"../images/license/ico_download_file_16_gray.png", //"DownloadIcon"
           5 :"../images/license/ico_remove_code_16_gray.png"}; //"TrashIcon"
        return map[buttonIcon];
    }
    Flickable
    {
        id:scrollPane
        objectName:	"scrollPane"
        contentHeight:content.height + choiceBar.verticalMargin * 2
        width:parent.width
        height:parent.height;

        Column
        {
            id:content
            objectName:	"content"
            anchors.top: parent.top; anchors.topMargin: choiceBar.verticalMargin
            anchors.left: parent.left; anchors.leftMargin:20
            anchors.right: parent.right; anchors.rightMargin:20
            spacing: 6
            visible: headerText.text != "" || !!headerImage.source || description.text != "" || buttonListModel.count > 0;
            
            Row
            {
            	id: header
            	width: parent.width
            	spacing: 7
	            Image
	            {
	            	id: headerImage
	            }
	            Text
	            {
	                id: headerText
	                width: header.width - header.spacing - headerImage.width
	                wrapMode: Text.WordWrap
	                visible: text != ""
	                font: commonFontStyles.standardSmallCaptionFont
	            }
	        }
            Text
            {
                id: description
                width:parent.width
                wrapMode: Text.WordWrap
                visible: text != ""
                font: commonFontStyles.standardCommonTextFont
            }
            Item
            {
                id: reserveCode
                objectName:	"reserveCode"
                width:parent.width
                height: reserveCodeText.text != "" ? reserveCodeText.height : 0
                Text
                {
                    id:reserveCodeText
                    wrapMode: Text.WordWrap
                    text: choiceBar.model.ReserveCode
                    font:commonFontStyles.standardSmallCaptionFont
                    color:"gray";
                }
                Image
                {
                    id: reserveCodeRemove
                    objectName:	"reserveCodeRemove"
                    source: "../images/license/Cross_ico.png";
                    anchors.left:reserveCodeText.right; anchors.leftMargin:3
                    anchors.verticalCenter:reserveCodeText.verticalCenter;
                    anchors.verticalCenterOffset:1
                    MouseArea
                    {
                        anchors.fill: parent
                        hoverEnabled: true;
                        onClicked:
                        {
                            if(choiceBar.model.DeleteReserveCodeAction != undefined)
                                choiceBar.model.DeleteReserveCodeAction.Invoke()
                        }

                        Clickable {}
                    }
                    visible: reserveCodeText.text != ""
                }
            }

            Flow
            {
                id:buttonList
                objectName:	"buttonList"
                width:parent.width
                spacing: 8
                Repeater
                {
					objectName:	"buttonListRepeater"
                    model:buttonListModel
                    GrayButton
                    {
						id: grayButton
                        text: model.modelData.name
                        objectName: model.modelData.objectName
                        iconImage:choiceBar.getButtonIcon(model.modelData.icon);
                        maxWidth: 300
                        onClicked:
                        {
                            if(model.modelData.action != undefined)
                                model.modelData.action.Invoke(Common.buildPath(parent)+"."+grayButton.objectName);
                            else if(model.modelData.panel != "") ; //TODO: panel navigation

                        }
                    }
                }
            }
        }
    }
}
