import Qt 4.7
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts

Item
{
	property variant context: MainWindow.parentalControl
	property variant commonFontStyles: Fonts.Common{}
	anchors.fill: parent
	objectName: "accountList"

	QtObject
	{
		id:style

		// style properties for item delegate
		property int itemHeight: 120
		property color itemColorFirst: "white"
		property color itemColorSecond: "#f0f0f0"
	}

	ListView
	{
		id: accounts
		objectName: "accounts"
		anchors.fill: parent
		model: MainWindow.parentalControl.UserList
		delegate: itemDelegate
		orientation : "Vertical"
		focus: true;
		currentIndex: 0;
	}

	Widgets.FlickableScrollBar
	{
		id:scrollbar
		target:         accounts
		anchors.top:    accounts.top;
		anchors.bottom: accounts.bottom;
		anchors.right:  accounts.right;
		width: 20
	}

	Component
	{
		id: itemDelegate

		Rectangle
		{
			id:itemBody
			objectName: "itemBody"

			property QtObject account:model.modelData

			
			anchors.left:parent.left
			anchors.right:parent.right
			height: style.itemHeight

			color: style.itemColorFirst;

			Image
			{
				id:iconElement

				anchors.left:parent.left; anchors.leftMargin:32
				anchors.verticalCenter:parent.verticalCenter
				source: {
				return {"Mother":"../common/images/parental_control/avatar_girl_01.png",
						"SonMajor":"../common/images/parental_control/avatar_son.png",
						"DotherMajor":"../common/images/parental_control/avatar_daughter.png",
						"SonMinor":"../common/images/parental_control/avatar_son_jr.png",
						"DotherMinor":"../common/images/parental_control/avatar_daughter_jr.png",
						"Father":"../common/images/parental_control/avatar_man_01.png",
						"":"../common/images/parental_control/avatar_man_01.png"}[account.iconId];
				}
			}

			Item
			{
				anchors.left:iconElement.right;anchors.leftMargin: 16
				anchors.right:btnOnOff.left;anchors.rightMargin:20

				Widgets.StandardCaptionText
				{
					id:accountName
					anchors.left:parent.left
					anchors.top:parent.top;
                    anchors.topMargin:32
					anchors.right: parent.right
					elide: Text.ElideRight
					text: account.name;
				}

				Row
				{
					anchors.left:parent.left;
                    anchors.top:accountName.bottom;anchors.topMargin: 10
					spacing: 5
					Image
					{
                        source: account.isControlEnabled ? "../common/images/parental_control/enabled.png" : "../common/images/parental_control/disabled.png"
						anchors.verticalCenter: parent.verticalCenter
					}
					Text
					{
						text: context.Localize(account.isControlEnabled ? "ControlIsTurnedOn" : "ControlIsTurnedOff")
                        color: account.isControlEnabled ? "#006a5d" : "#7b7b7b"
						anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: -1
                        font.pointSize: 10
					}
				}
			}

			Widgets.GrayButton
			{
				id: settingsBtn
				objectName: "ParCtlSettings" + index
				anchors.right:parent.right;anchors.rightMargin:32
				anchors.verticalCenter:parent.verticalCenter
                iconImage: "../images/parental_control/icons.png"
				onClicked: {account.settingsAction.Invoke()}
			}

			Widgets.GrayButton
			{
				id: btnOnOff
				objectName: "rememberCheckBox" + index
				anchors.right: settingsBtn.left
				anchors.rightMargin: 8
				anchors.verticalCenter: parent.verticalCenter
				text: context.Localize(account.isControlEnabled ? "TurnOff" : "TurnOn")
				minWidth: 90
				onClicked: account.isControlEnabled ? context.DisableParentalControl(account.id) : context.EnableParentalControl(account.id)
			}
			Image {
				anchors.bottom: parent.bottom
				width: parent.width
				source: "../common/images/inner/list_separator.png"
			}
		}
	}
}
