import Qt 4.7
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts

Rectangle
{
	id: itemHolder
	objectName: "itemHolder"
	property string title
	property string description
	property int problemState
	property variant actions	
    property bool isDescriptionMultiline
	property int type

	clip: true
	color: style.itemColor
	border.color: style.itemBorderColor

	// http://bugreports.qt.nokia.com/browse/QTBUG-14847
	// AnimatedImage does not use pixmap cache, so we use AnimatedImage only if really needed
	Row
	{
		id: stateIcon
		anchors.left: parent.left; anchors.leftMargin: 20
		anchors.top: textGroup.top; anchors.topMargin: 4
		
		Image 
		{
			visible: problemState != 3
			source: {
				switch (problemState)
				{
					case 0: return Qt.resolvedUrl("../common/images/ico_info_32.png");
					case 1: return Qt.resolvedUrl("../common/images/ico_warning_32.png");
					case 2: return Qt.resolvedUrl("../common/images/ico_danger_32.png");
					default: ''
				}
			}
		}
		
		AnimatedImage 
		{
			visible: problemState == 3
			source: problemState == 3 ? Qt.resolvedUrl("../common/images/loader_32.gif"): ''
		}		
	}
	
	
	Item
	{
		id:textGroup
		anchors.left:stateIcon.right; anchors.leftMargin:20
		anchors.right: itemActions.left;
		property int textGap: 5
		anchors.verticalCenter: parent.verticalCenter
		anchors.verticalCenterOffset: -2
		height: titleText.height + textGap + descriptionText.height;
		// title text
		Text
		{
			id: titleText
			anchors.left:parent.left;
			anchors.right: parent.right;			
			anchors.top: parent.top;
			
			font: commonFontStyles.standardSmallCaptionFont
			text: title
			wrapMode: Text.Wrap
		}
		// description text
		Text
		{
			id:descriptionText
			anchors.left:parent.left;
			anchors.right:parent.right;
			anchors.top: titleText.bottom; anchors.topMargin: parent.textGap

			wrapMode: isDescriptionMultiline ? Text.WordWrap : Text.NoWrap
			font: commonFontStyles.standardCommonTextFont
			color: "black";
			text: description;
			elide: isDescriptionMultiline ? Text.ElideNone : Text.ElideMiddle
		}
	}
	Image
	{
		anchors.top: parent.top
		width: parent.width
		source: "../common/images/inner/list_separator.png"
	}
	
	// actions
	Item
	{
		id:itemActions
		objectName: "itemActions"
		anchors.right: parent.right; anchors.rightMargin: 20
		anchors.top: textGroup.top; anchors.topMargin: 2
		width: 130;
		Widgets.DPIScaler{changeWidth:true}
		visible: actions != undefined && actions[0] != undefined
		
		
		Widgets.ComboButton
		{
			objectName: "action"
			actionList: actions != undefined && actions[0] != undefined ? actions : []
			minWidth: parent.width
			maxWidth: parent.width
			property QtObject tempElement
			onPressed:
			{
				if(index < actions.length)
				{
					tempElement = actions[index];
					if (tempElement.action != undefined)
						tempElement.action.Invoke()
				}
			}
		}
	}
	
}

