import Qt 4.7
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../main_window" as MainFrame

MainFrame.InnerContent
{
    id: scanPanel
    objectName: "ScanPanel"
	caption: MainWindow.Localize("Scan")
	property int helpId: 43663

	captionArea: Component
	{
		Item 
		{
			clip:           false
			property variant context: MainWindow.Scan
			objectName:	"captionArea"

			Widgets.CaptionButton
			{
				id: 		taskManager
				objectName:	"taskManagerButton"
				
				text:		context.Localize("TaskManager")
				onClicked:	context.ShowShowTaskManager.Invoke()
			}
            Widgets.Loading16
			{
				id:			runningAnimation
				x:			taskManager.x - 1.5 * width
				anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
				visible: context.HasActiveTasks
			}
		}
	}

	viewArea: Component
	{
		Item
		{
			property variant context: MainWindow.Scan
			property variant commonFontStyles: Fonts.Common{}

			id: 		scanPanel
			objectName:	"ScanPanel"
			anchors.fill: parent
			clip:		false

            Widgets.DPIScaler { id: scaler }
            property int itemWidth:		327 * scaler.factor
            property int itemHeight:	163 * scaler.factor
            property int margin: 15

			Loader
			{
			    id: fullScanTaskLoader
				objectName:		"FullScanLoader"
				width:			scanPanel.itemWidth
				height:			scanPanel.itemHeight
                anchors.top: parent.top
                anchors.topMargin: scanPanel.margin
                anchors.left: parent.left
                anchors.leftMargin: scanPanel.margin
                property variant task: MainWindow.Scan.FullScan
                onTaskChanged: { sourceComponent = undefined; sourceComponent = fullScanTaskComponent; }
			}
			
			Component
			{
				id: fullScanTaskComponent;
				ScanTask
				{
					id: fullScanTask
					objectName:		"FullScan"
					context:		MainWindow.Scan
					anchors.fill: parent
					Binding
					{
						target: fullScanTask; property: 'contextScan';
						value: context.FullScan;
					}

					scanHeader:		contextScan.Localize("FullScan_Title")
					firstTimeRun:	contextScan.Localize("FullScan_Description")
					askStopScan:	contextScan.Localize("FullScan_StopConfirmation")
					askResumeScan:	contextScan.Localize("FullScan_ResumeConfirmation")
				}
			}			

			ScanTask
			{
                id: criticalAreaScanTask
				objectName:		"CriticalAreaScan"
				width:			scanPanel.itemWidth
				height:			scanPanel.itemHeight
                anchors.top: parent.top
                anchors.topMargin: scanPanel.margin
                anchors.right: parent.right
                anchors.rightMargin: scanPanel.margin
				context:		parent.context
				contextScan:	context.CriticalAreaScan

				scanHeader:		contextScan.Localize("CriticalAreaScan_Title")
				firstTimeRun:	contextScan.Localize("CriticalAreaScan_Description")
				askStopScan:	contextScan.Localize("CriticalAreaScan_StopConfirmation")
				askResumeScan:	contextScan.Localize("CriticalAreaScan_ResumeConfirmation")
			}
			ScanTask
			{
                id: velnerabilityScanTask
				objectName:		"VulnerabilityScan"
				width:			scanPanel.itemWidth
				height:			scanPanel.itemHeight
                anchors.left: parent.left
                anchors.leftMargin: scanPanel.margin
                anchors.top: fullScanTaskLoader.bottom
                anchors.topMargin: criticalAreaScanTask.x - (fullScanTaskLoader.x + fullScanTaskLoader.width)
				context:		parent.context
				contextScan: 	context.VulnerabilityScan

				scanHeader:		contextScan.Localize("VulnerabilityScan_Title")
				firstTimeRun:	contextScan.Localize("VulnerabilityScan_Description")
				askStopScan:	contextScan.Localize("VulnerabilityScan_StopConfirmation")
			}

			Rectangle // Drag&Drop
			{
				objectName: "DragAndDropScan"
				width: scanPanel.itemWidth
				height: scanPanel.itemHeight
				color: "transparent"
				property variant context: scanPanel.context
                anchors.top: velnerabilityScanTask.top
                anchors.left: criticalAreaScanTask.left

				FileDropArea
				{
					anchors.fill: parent
					onDropped: context.StartScanTask(fileList)
				}

				Image
				{
                    y: -5
					id: dragAndDropImage
					objectName: "DragAndDropArea"
					source: "../common/images/scan/scaner.png"
                    Widgets.DPIScaler { changeSize: true }
					Text
					{
						id: dropAreaText
                        y: 110 * scaler.factor
						anchors.horizontalCenter: parent.horizontalCenter
						horizontalAlignment: Text.AlignHCenter
						objectName: "ScanLinkArea"
						width: parent.width - 60
						color: "Black"
						font: commonFontStyles.standardCommonTextFont
						wrapMode: Text.WordWrap
						textFormat: Text.RichText
						text: parent.parent.parent.context.VulnerabilityScan.Localize("CustomAreaScan_Description")
					}

					MouseArea
					{
						anchors.fill: parent
						onClicked: context.ShowCustomScanSelectObjects.Invoke()
						hoverEnabled: true
						Widgets.Clickable {}
					}
				}
			}
		}
	}
}
