import Qt 4.7
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts

Widgets.PageFrame
{
	property variant context: (typeof MainWindow == "undefined") ? WelcomePage : MainWindow.welcomePage

	id: welcomePage
	objectName: "welcomePage"
	anchors.fill: parent

    property variant commonFontStyles: Fonts.Common{}

	windowDescriptionText: context.Localize("WelcomPageTitle")

	hasBanner: false
	helpButtonVisible: false
	nextButtonVisible: false
	nextButtonText: context.Localize("BuyButton")
    nextButtonStyle: Widgets.GreenStyle {}
    nextButtonIconImage: "../images/startup/icon_buy.png"
    nextButtonWidth: 0
	cancelButtonText: context.Localize("CloseButton")

	onNext:	context.PurchaseLicenseAction.Invoke(objectPath)
	Connections {onClose: if (!parent) Window.Close();}

	Item
	{
		id: workingArea
		objectName: "workingArea"
		anchors.fill: parent
        anchors.topMargin: 29
        anchors.leftMargin: 10
        anchors.bottomMargin: 43
        anchors.rightMargin: 10
		clip: true

		Image
		{
			anchors.fill: parent
			source: "../common/images/startup/pattern.png"
			fillMode: Image.Tile
		}

        Widgets.StandardCaptionText
		{
			id: titleText
			width: parent.width*0.8
            height: 90
			wrapMode: Text.Wrap
			smooth: true
			horizontalAlignment: Text.AlignHCenter
			verticalAlignment: Text.AlignBottom
			anchors.horizontalCenter: parent.horizontalCenter
			text: context.Localize("WelcomeHeader")
		}

		Row
		{
			id: row
			y: 120
			width: parent.width
			height: parent.height - 220
			spacing: 0

			function getFeatureImage(FeatureId)
			{
				switch(FeatureId)
				{
					case "InternetShopping": return "../common/images/startup/ico_internet_shopping_96.png"
					case "ReputationFiles": return "../common/images/startup/ico_file_reputation_96.png"
					case "ParentalControl": return "../common/images/startup/ico_parental_control_96.png"
					case "Sandbox": return "../common/images/startup/ico_safe_desktop_96.png"
					case "RescueDisk": return "../common/images/startup/ico_rescue_disk_96.png"
					case "SearchVulnerab": return "../common/images/startup/ico_vulnerability_scan_96.png"
					case "WarningURL": return "../common/images/startup/ico_link_warning_96.png"
					case "GameMode": return "../common/images/startup/ico_game_mode_96.png"
					case "AntiBanner": return "../common/images/startup/ico_anti_banner_96.png"
					case "HistoryActivity": return "../common/images/startup/ico_activity_trails_remove_96.png"
					default: return "../common/images/startup/ico_medal_96.png"
				}
			}

			function getNewVisibility(FeatureId)
			{
				switch(FeatureId)
				{
					case "InternetShopping": return false
					case "ReputationFiles": return true
					case "ParentalControl": return false
					case "Sandbox": return false
					case "RescueDisk": return false
					case "SearchVulnerab": return false
					case "WarningURL": return false
					case "GameMode": return false
					case "AntiBanner": return false
					case "HistoryActivity": return false
					default: return false
				}
			}

			function getUpgradeVisibility(FeatureId)
			{
				switch(FeatureId)
				{
					case "InternetShopping": return false
					case "ReputationFiles": return false
					case "ParentalControl": return true
					case "Sandbox": return true
					case "RescueDisk": return true
					case "SearchVulnerab": return false
					case "WarningURL": return true
					case "GameMode": return false
					case "AntiBanner": return false
					case "HistoryActivity": return false
					default: return false
				}
			}

			Column
			{
				id: column1
                width: parent.width*0.32
				height: parent.height
				spacing: 8

				Item
				{
					width: parent.width;
					height: 104
					Image
					{
						id: image1
						anchors.horizontalCenter: parent.horizontalCenter
						source: row.getFeatureImage(context.FirstFeatureCode);
					}

					Image
					{
						x: image1.x + 70
						y: image1.y + 75
						source: "../common/images/startup/label.png"
						visible: row.getNewVisibility(context.FirstFeatureCode);

						Text
						{
							anchors.centerIn: parent
							text: context.Localize("New");
							smooth: true
						}
					}

					Image
					{
						x: image1.x + 70
						y: image1.y + 75
						source: "../common/images/startup/label.png"
						visible: row.getUpgradeVisibility(context.FirstFeatureCode);

						Text
						{
							anchors.centerIn: parent
							text: context.Localize("Upgrade");
							smooth: true
						}
					}
				}

				Text
				{
                    x: 24
					width: parent.width - 40
					text: context.Localize("Header_" + context.FirstFeatureCode)
					color: "#5E5E5E"
					font.pointSize: 10
					font.bold: true
					font.family: "Franklin Gothic Book"
					wrapMode: Text.Wrap
				}
				Text
				{
                    x: 24
					width: parent.width - 40
					text: context.Localize("Description_" + context.FirstFeatureCode)
					color: "#909090"
					font.pointSize: 10
					font.family: "Franklin Gothic Book"
					smooth: true
					wrapMode: Text.Wrap
					clip: true
				}
			}

			Image
			{
				anchors.verticalCenter: parent.verticalCenter
                source: "../common/images/startup/separator.png"
			}

			Column
			{
				id: column2
                width: parent.width*0.32
				height: parent.height
				spacing: 10

				Item
				{
					width: parent.width;
					height: 104
					Image
					{
						id: image2
						anchors.horizontalCenter: parent.horizontalCenter
						source: row.getFeatureImage(context.SecondFeatureCode);
					}

					Image
					{
						x: image2.x + 70
						y: image2.y + 75
						source: "../common/images/startup/label.png"
						visible: row.getNewVisibility(context.SecondFeatureCode);

						Text
						{
							anchors.centerIn: parent
							text: context.Localize("New");
							smooth: true
						}
					}

					Image
					{
						x: image2.x + 70
						y: image2.y + 75
						source: "../common/images/startup/label.png"
						visible: row.getUpgradeVisibility(context.SecondFeatureCode);

						Text
						{
							anchors.centerIn: parent
							text: context.Localize("Upgrade");
							smooth: true
						}
					}
				}

				Text
				{
                    x: 20
					width: parent.width - 40
					text: context.Localize("Header_" + context.SecondFeatureCode)
					color: "#5E5E5E"
					font.pointSize: 10
					font.bold: true
					font.family: "Franklin Gothic Book"
					wrapMode: Text.Wrap
				}
				Text
				{
                    x: 20
					width: parent.width - 40
					text:context.Localize("Description_" + context.SecondFeatureCode)
					color: "#909090"
					font.pointSize: 10
					font.family: "Franklin Gothic Book"
					smooth: true
					wrapMode: Text.Wrap
					clip: true
				}
			}

			Image
			{
				anchors.verticalCenter: parent.verticalCenter
				source: "../common/images/startup/separator.png"
			}

			Column
			{
				id: column3
                width: parent.width*0.32
				height: parent.height
				spacing: 10

				Item
				{
					width: parent.width;
					height: 104
					Image
					{
						id: image3
						anchors.horizontalCenter: parent.horizontalCenter
						source: row.getFeatureImage(context.ThirdFeatureCode);
					}

					Image
					{
						x: image3.x + 70
						y: image3.y + 75
						source: "../common/images/startup/label.png"
						visible: row.getNewVisibility(context.ThirdFeatureCode);

						Text
						{
							anchors.centerIn: parent
							text: context.Localize("New");
							smooth: true
						}
					}

					Image
					{
						x: image3.x + 70
						y: image3.y + 75
						source: "../common/images/startup/label.png"
						visible: row.getUpgradeVisibility(context.ThirdFeatureCode);

						Text
						{
							anchors.centerIn: parent
							text: context.Localize("Upgrade");
							smooth: true
						}
					}
				}

				Text
				{
                    x: 20
					width: parent.width - 40
					text: context.Localize("Header_" + context.ThirdFeatureCode)
					color: "#5E5E5E"
					font.pointSize: 10
					font.bold: true
					font.family: "Franklin Gothic Book"
					wrapMode: Text.Wrap
				}
				Text
				{
                    x: 20
					width: parent.width - 40
					text:context.Localize("Description_" + context.ThirdFeatureCode)
					color: "#909090"
					font.pointSize: 10
					font.family: "Franklin Gothic Book"
					smooth: true
					wrapMode: Text.Wrap
					clip: true
				}
			}
		}

		Image
		{
            y: parent.height - 70
			anchors.horizontalCenter: parent.horizontalCenter
			source: "../common/images/startup/paperpress.png"
		}

        Widgets.GrayButton
		{
            y: parent.height - 50
			anchors.horizontalCenter: parent.horizontalCenter
			id:			detail
			objectName: "detail"
			text:			context.Localize("Detail")
            horizontalMargin:	15
			verticalMargin:		8

			onClicked: context.ShowMoreInfoAction.Invoke()
		}

	}

	Widgets.CheckBox
	{
		id:  showScreenCheckBox
		objectName: "showScreenCheckBox"
		anchors.left: workingArea.left
		anchors.top: workingArea.bottom
        anchors.topMargin: 13
        anchors.leftMargin: -2
        horizontalMargin: 6
        textVerticalMargin: 1
		text: context.Localize("DoNoyShowThisWindow")
		color:		"transparent"
		checked: !context.ShowScreen
	}
	Binding {target: context; property: "ShowScreen"; value: !showScreenCheckBox.checked }
}
